@@ -11,15 +11,16 @@
 """ Defines the DataView class, and associated property traits and property
 functions.
 """
-from numpy import array, transpose
+from numpy import array, empty, transpose
 
-from traits.api import Bool, Enum, Instance, Property
+from traits.api import Bool, Enum, Instance, Int, Property, Union
 from enable.api import color_table
 
 from .abstract_overlay import AbstractOverlay
 from .axis import PlotAxis
 from .base_1d_mapper import Base1DMapper
 from .base_2d_plot import Base2DPlot
+from .chaco_traits import Optional
 from .data_range_2d import DataRange2D
 from .grid import PlotGrid
 from .linear_mapper import LinearMapper
@@ -217,11 +218,71 @@ class DataView(OverlayPlotContainer):
     #: Background color (overrides Enable Component)
     bgcolor = "white"
 
-    #: Padding defaults.
-    padding_top = 50
-    padding_bottom = 50
-    padding_left = 50
-    padding_right = 50
+    # Padding defaults. These were converted to properties as a hacky fix for
+    # enthought/chaco#564
+    #: Top Padding default
+    padding_top = Property(
+        observe='y_axis.[title,orientation], x_axis.[title,orientation]'
+    )
+    #: Bottom Padding default
+    padding_bottom = Property(
+        observe='y_axis.[title,orientation], x_axis.[title,orientation]'
+    )
+    #: Left Padding default
+    padding_left = Property(
+        observe='y_axis.[title,orientation], x_axis.[title,orientation]'
+    )
+    #: Right Padding default
+    padding_right = Property(
+        observe='y_axis.[title,orientation], x_axis.[title,orientation]'
+    )
+
+    _padding_top = Optional(Int())
+    _padding_bottom = Optional(Int())
+    _padding_left = Optional(Int())
+    _padding_right = Optional(Int())
+
+    def _find_padding(self, side):
+        SIDE_TO_TRAIT_MAP = {
+            "top": "_padding_top",
+            "bottom": "_padding_bottom",
+            "left": "_padding_left",
+            "right": "_padding_right",
+        }
+        if getattr(self, SIDE_TO_TRAIT_MAP[side]) is not None:
+            return getattr(self, SIDE_TO_TRAIT_MAP[side])
+        else:
+            if self.y_axis:
+                if (self.y_axis.title and self.y_axis.orientation == side):
+                    return 80
+            if self.x_axis:
+                if (self.x_axis.title and self.x_axis.orientation == side):
+                    return 80
+            return 50
+
+    def _get_padding_top(self):
+        return self._find_padding("top")
+
+    def _get_padding_bottom(self):
+        return self._find_padding("bottom")
+
+    def _get_padding_left(self):
+        return self._find_padding("left")
+
+    def _get_padding_right(self):
+        return self._find_padding("right")
+
+    def _set_padding_top(self, value):
+        self._padding_top = value
+
+    def _set_padding_bottom(self, value):
+        self._padding_bottom = value
+
+    def _set_padding_left(self, value):
+        self._padding_left = value
+
+    def _set_padding_right(self, value):
+        self._padding_right = value
 
     border_visible = True
 
@@ -244,7 +305,7 @@ class DataView(OverlayPlotContainer):
         """
         # data_array is Nx2 array
         if len(data_array) == 0:
-            return []
+            return empty(shape=(0, 2))
         x_ary, y_ary = transpose(data_array)
         sx = self.index_mapper.map_screen(x_ary)
         sy = self.value_mapper.map_screen(y_ary)
